#
# spec file for package grandorgue
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define version_suffix 1

Name:           grandorgue
Version:        3.9.4
Release:        1.1
Summary:        Virtual Pipe Organ Software
License:        GPL-2.0-or-later
URL:            https://github.com/GrandOrgue/grandorgue
Source:         https://github.com/GrandOrgue/grandorgue/archive/%{version}-%{version_suffix}.tar.gz#/%{name}-%{version}-%{version_suffix}.tar.gz
BuildRequires:  ImageMagick
BuildRequires:  cmake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools
BuildRequires:  hicolor-icon-theme
BuildRequires:  libxslt-tools
BuildRequires:  po4a
BuildRequires:  update-desktop-files
BuildRequires:  wxGTK3-devel
BuildRequires:  zip
BuildRequires:  zita-convolver-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fftw3f)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(rtaudio)
BuildRequires:  pkgconfig(rtmidi)
BuildRequires:  pkgconfig(wavpack)
BuildRequires:  pkgconfig(zlib)
Recommends:     grandorgue-demo

%package demo
Summary:        GrandOrgue demo sampleset
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Midi
BuildArch:      noarch

%description
GrandOrgue is a virtual pipe organ sample player application supporting a HW1 compatible file format.

%description demo
This package contains the demo sampleset for GrandOrgue.

%prep
%setup -qn %{name}-%{version}-%{version_suffix}

%build
%cmake -DDOC_INSTALL_DIR=%{_docdir} \
       -DLIBINSTDIR=%{_lib} \
       -DUSE_INTERNAL_RTAUDIO=OFF \
       -DUSE_INTERNAL_PORTAUDIO=OFF \
       -DUSE_INTERNAL_ZITACONVOLVER=OFF
%cmake_build

%install
%cmake_install
mkdir -p %{buildroot}%{_docdir}/%{name}
install -m 644 README* %{buildroot}%{_docdir}/%{name}
%find_lang GrandOrgue
%suse_update_desktop_file GrandOrgue

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f GrandOrgue.lang
%{_bindir}/*
%{_libdir}/libGrandOrgue*
%dir %{_datadir}/GrandOrgue/packages
%dir %{_datadir}/GrandOrgue
%doc %{_docdir}/%{name}
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/*
%{_datadir}/GrandOrgue/help
%{_datadir}/GrandOrgue/sounds
%{_datadir}/GrandOrgue/perftests
%{_datadir}/applications/*
%{_datadir}/mime/packages/*
%{_datadir}/icons/hicolor/*
%{_mandir}/man1/*

%files demo
%{_datadir}/GrandOrgue/packages/*.orgue

%changelog
* Tue Dec 13 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.9.4-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.9.4-1
  * Fixed starting 3.9.3 on Windows #1311
- Update to version 3.9.3-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.9.3-1
  * Fixed an old version number in the gnome application metadata #1304
  * Fixed switching off generals when using crescendo in not override mode #1299
  * Fixed error messages of GrandOrguePerf #1280
  * Fixed exit from GrandOrgue with an unhandled exception occurred on loading an organ
  * Fixed displaying output volume indicators on OSx #1255
  * Fixed sending midi-off events from generals and another pushbuttons #1291
  * Fixed crashing on exit in some cases
* Tue Nov 29 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.9.2-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.9.2-1
  * Fixed sending incorrect midi values from an enclosure #1267
  * Fixed not sending midi events from pushbuttons, including GC #1220
  * Fixed sending a midi event from an enclosure when it's value is not changed #1206
  * Fixed processing enclosures with high value is less than low value #1266
* Mon Nov 14 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.9.1-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.9.1-1
  * Fixed crash on loading an organ without a pedal #1249
  * Fixed SYSEX Hauptwerk max. length in MIDI event editor #1207
  * Fixed enclosure value calculation #1203
  * Fixed controlling stops with a touchscreen on Raspberry Pi #1208
* Thu Nov  3 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.9.0-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.9.0-1
  * Fixed playing multitrack midi files with changes of tempo https://github.com/GrandOrgue/grandorgue/discussions/1225
  * Fixed displaying audio ports on OSx #1216
  * Added divisional combination banks #708
  * Renamed audio ports: Pa to PortAudio and Rt to RtAudio #1216
  * Fixed size of the Organ Selection Dialog #1215
  * Fixed generals buttons behaviour with the crescendo in add mode #1209
  * Fixed an empty stop set to a general combination #1212
* Thu Sep 15 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.8.0-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.8.0-1
  * Fixed setting an empty stop set to a divisional combination #1068
  * Added capability of switching between the Override and the Add crescendo mode #1170
  * Fixed rebuilding the cache every time upon the appimage starts #1174
  * Fixed building appimage in an ubuntu container
* Tue Aug 16 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.7.0-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.7.0-1
  * Fixed packaging for OSx #1135
  * Deleting an organ in the Organ tab of the Settings dialog causes also deleting it's cache and all it's presets #1049
  * Reorganised the Organs tab of the Settings dialog #1119
  * Added capability of restoring organ settings values for all subobjects #1119
* Sun May 22 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.6.7-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.6.7-1
  * Added publishing debug symbols on windows builds #853
* Fri Apr 29 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.6.6-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.6.6-1
  * Fixed help issues #1066
  * Fixed saving organ settings on closing an organ or on finishing GrandOrgue #1069
  * Fixed setting up output midi events for all devices #1097
* Mon Apr 18 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.6.5-1.
  Changelog: https://github.com/GrandOrgue/grandorgue/releases/tag/3.6.5-1
  * Fixed not saving the main window position and size in organ settings #1093
  * Fixed sound distortion while a reveberation is active #983
  * Fixed hang on reopening sound device (exit from settings, Panic) while a reveberation is active #983
  * Added support for building against system-wide ZitaConvolver library #1095
* Sun Mar 20 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.6.4-1.
  * Updated the copyright headers in the source code
  * Switched ZitaConvolver to an external source (github#983)
  * Added distribution of GrandOrguePerfTest in the GrandOrgue package (github#868)
  * Added the image file name to messages on loading this image (github#1063)
  * Fixed allowing to select disabled devices in the Midi Event Dialog (github#1044)
  * Fixed limits for PGM numbers of the Cx Program Change Range midi event (github#1058)
  * Clarified the guide how to obtain submodule sources manually in the BUILD.md (github#1062)
* Sat Mar  5 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.6.3-1.
* Sat Jan 29 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 3.6.1-1.
* Wed Jan 26 2022 Lukas Müller <expeehaa@outlook.com>
- Create package with version 3.6.1-0.
